.. _symbolic-calculus:

Symbolic Calculus
=================

Calculus is done using symbolic expressions which consist
of symbols and numeric objects linked by operators (functions).

.. NOTE::

    While polynomial manipulation can be done with expressions,
    it is more efficient to use polynomial ring elements

Using calculus
^^^^^^^^^^^^^^

- :doc:`sage/calculus/calculus`
- Examples

  - :doc:`Calculus examples <sage/calculus/test_sympy>`
  - :doc:`sage/calculus/tests`
  - :doc:`sage/calculus/wester`

- :doc:`More about symbolic variables and functions <sage/calculus/var>`
- :doc:`Main operations on symbolic expressions <sage/symbolic/expression>`
- :doc:`sage/calculus/expr`
- :doc:`Assumptions about symbols and functions <sage/symbolic/assumptions>`
- :doc:`sage/symbolic/relation`
- :doc:`sage/symbolic/integration/integral`
- :doc:`sage/calculus/desolvers`
- :doc:`sage/calculus/ode`
- :doc:`sage/calculus/integration`
- :doc:`sage/calculus/interpolation`
- Transforms

  - :doc:`sage/calculus/transforms/dwt`
  - :doc:`sage/calculus/transforms/dft`
  - :doc:`sage/calculus/transforms/fft`

- :ref:`Vector Calculus <euclidean-spaces>`
- :doc:`sage/calculus/riemann`
- :doc:`Other calculus functionality <sage/calculus/functions>`
- :doc:`sage/symbolic/complexity_measures`
- :doc:`sage/symbolic/units`

Internal functionality supporting calculus
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

- :doc:`sage/symbolic/ring`
- :doc:`sage/symbolic/subring`
- :doc:`sage/symbolic/operators`
- :doc:`sage/symbolic/function`
- :doc:`sage/calculus/functional`
- :doc:`sage/symbolic/function_factory`
- :doc:`Internals of Callable Symbolic Expressions <sage/symbolic/callable>`
- :doc:`sage/symbolic/expression_conversions`
- :doc:`sage/symbolic/benchmark`
- :doc:`sage/symbolic/random_tests`
- :doc:`sage/symbolic/maxima_wrapper`
- :doc:`External integrators <sage/symbolic/integration/external>`
- :doc:`External interpolators <sage/calculus/interpolators>`


.. toctree::
   :hidden:

   sage/symbolic/expression
   sage/symbolic/callable
   sage/calculus/expr
   sage/symbolic/assumptions
   sage/symbolic/relation
   sage/calculus/calculus
   sage/symbolic/units
   sage/symbolic/ring
   sage/symbolic/subring
   sage/symbolic/function
   sage/symbolic/function_factory
   sage/calculus/functional
   sage/symbolic/integration/integral
   sage/symbolic/integration/external
   sage/calculus/test_sympy
   sage/calculus/tests
   sage/symbolic/expression_conversions
   sage/symbolic/complexity_measures
   sage/calculus/wester
   sage/calculus/desolvers
   sage/calculus/transforms/dwt
   sage/calculus/transforms/dft
   sage/calculus/transforms/fft
   sage/calculus/ode
   sage/calculus/integration
   sage/calculus/riemann
   sage/calculus/interpolation
   sage/calculus/interpolators
   sage/calculus/functions
   sage/calculus/var
   sage/symbolic/maxima_wrapper
   sage/symbolic/operators
   sage/symbolic/benchmark
   sage/symbolic/random_tests

.. include:: ../footer.txt
